aboutsummaryrefslogtreecommitdiff
path: root/include/libsurvive/survive.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/libsurvive/survive.h')
-rw-r--r--include/libsurvive/survive.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/libsurvive/survive.h b/include/libsurvive/survive.h
index 03a71bc..7a0ed1e 100644
--- a/include/libsurvive/survive.h
+++ b/include/libsurvive/survive.h
@@ -37,8 +37,8 @@ struct SurviveObject
PoserCB PoserFn;
//Device-specific information about the location of the sensors. This data will be used by the poser.
- int8_t nr_locations; // sensor count
- FLT * sensor_locations; // size is nr_locations*3. Contains x,y,z values for each sensor
+ int8_t sensor_ct; // sensor count
+ FLT * sensor_locations; // size is sensor_ct*3. Contains x,y,z values for each sensor
FLT * sensor_normals;// size is nrlocations*3. cointains normal vector for each sensor
//Timing sensitive data (mostly for disambiguation)